@@ -1,4 +1,4 @@
-from typing import Dict, List, Tuple, TypedDict
+from typing import Dict, List, Tuple, TypedDict, Literal
 
 
 class PrivateSequence(TypedDict):
@@ -10,4 +10,8 @@ PrivateMessage = PrivateSequence
 # Note that these don't match quite Orderbook update messages which may have 5 values
 PublicMessage = Dict
 
-UserFeedMessage = PrivateMessage | PublicMessage
\ No newline at end of file
+UserFeedMessage = PrivateMessage | PublicMessage
+
+
+class UserDataStreamMessage(TypedDict):
+    e: Literal["outboundAccountInfo", "executionReport", "outboundAccountPosition"]
